@@ -9,7 +9,7 @@ import numpy as np
 import pytest
 
 
-@pytest.fixture(autouse=True)
+@pytest.fixture(scope="function", autouse=True)
 def suppressing():
     """ helper function adjusting message reporting for all tests """
     # raise all underflow errors
