@@ -57,9 +57,9 @@ class FieldBase(metaclass=ABCMeta):
     ):
         """
         Args:
-            grid (:class:`~pde.grids.GridBase`):
+            grid (:class:`~pde.grids.base.GridBase`):
                 Grid defining the space on which this field is defined
-            data (array, optional):
+            data (:class:`~numpy.ndarray`, optional):
                 Field values at the support points of the grid
             label (str, optional):
                 Name of the field
@@ -554,7 +554,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
     """abstract base class for describing fields of single entities
 
     Attributes:
-        grid (:class:`~pde.grids.GridBase`):
+        grid (:class:`~pde.grids.base.GridBase`):
             The underlying grid defining the discretization
         data (:class:`~numpy.ndarray`):
             Data values at the support points of the grid
@@ -577,7 +577,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
     ):
         """
         Args:
-            grid (:class:`~pde.grids.GridBase`):
+            grid (:class:`~pde.grids.base.GridBase`):
                 Grid defining the space on which this field is defined.
             data (Number or :class:`~numpy.ndarray`, optional):
                 Field values at the support points of the grid. The data is copied from
@@ -649,7 +649,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         These values are uncorrelated in space.
 
         Args:
-            grid (:class:`~pde.grids.GridBase`):
+            grid (:class:`~pde.grids.base.GridBase`):
                 Grid defining the space on which this field is defined
             vmin (float):
                 Smallest possible random value
@@ -682,7 +682,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         These values are uncorrelated in space.
 
         Args:
-            grid (:class:`~pde.grids.GridBase`):
+            grid (:class:`~pde.grids.base.GridBase`):
                 Grid defining the space on which this field is defined
             mean (float):
                 Mean of the Gaussian distribution
@@ -747,7 +747,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         function given by the parameter `harmonic`.
 
         Args:
-            grid (:class:`~pde.grids.GridBase`):
+            grid (:class:`~pde.grids.base.GridBase`):
                 Grid defining the space on which this field is defined
             modes (int):
                 Number :math:`M` of harmonic modes
@@ -810,7 +810,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         uncorrelated.
 
         Args:
-            grid (:class:`~pde.grids.GridBase`):
+            grid (:class:`~pde.grids.base.GridBase`):
                 Grid defining the space on which this field is defined
             exponent (float):
                 Exponent :math:`\nu` of the power spectrum
@@ -1202,7 +1202,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         """interpolate the data of this field to another grid.
 
         Args:
-            grid (:class:`~pde.grids.GridBase`):
+            grid (:class:`~pde.grids.base.GridBase`):
                 The grid of the new field onto which the current field is
                 interpolated.
             backend (str):
@@ -1737,14 +1737,23 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             :class:`PlotReference`: Instance that contains information to update
             the plot with new data later.
         """
-        # do the plotting using the chosen method
+        # store the parameters of this plot for later updating
+        parameters = {
+            "method": method,
+            "transpose": transpose,
+            "kwargs": kwargs,
+        }
+
         if method == "quiver":
+            # plot vector field using a quiver plot
             data = self.get_vector_data(transpose=transpose, max_points=max_points)
+            parameters["max_points"] = max_points  # only save for quiver plot
             element = ax.quiver(
                 data["x"], data["y"], data["data_x"].T, data["data_y"].T, **kwargs
             )
 
         elif method == "streamplot":
+            # plot vector field using a streamplot
             data = self.get_vector_data(transpose=transpose)
             element = ax.streamplot(
                 data["x"], data["y"], data["data_x"].T, data["data_y"].T, **kwargs
@@ -1759,12 +1768,6 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         ax.set_ylabel(data["label_y"])
         ax.set_title(data.get("title", self.label))
 
-        parameters = {
-            "method": method,
-            "transpose": transpose,
-            "max_points": max_points,
-            "kwargs": kwargs,
-        }
         return PlotReference(ax, element, parameters)
 
     def _update_vector_plot(self, reference: PlotReference) -> None:
@@ -1774,14 +1777,18 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             reference (:class:`PlotReference`):
                 The reference to the plot that is updated
         """
+        # extract general parameters
         method = reference.parameters.get("method", "quiver")
         transpose = reference.parameters.get("transpose", False)
+
         if method == "quiver":
+            # update the data of a quiver plot
             max_points = reference.parameters.get("max_points")
             data = self.get_vector_data(transpose=transpose, max_points=max_points)
             reference.element.set_UVC(data["data_x"], data["data_y"])
 
         elif method == "streamplot":
+            # update a streamplot by redrawing it completely
             ax = reference.ax
             kwargs = reference.parameters.get("kwargs", {})
             data = self.get_vector_data(transpose=transpose)
@@ -1789,7 +1796,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             ax.cla()
             # update with new streamplot
             reference.element = ax.streamplot(
-                data["x"], data["y"], data["data_x"], data["data_y"], **kwargs
+                data["x"], data["y"], data["data_x"].T, data["data_y"].T, **kwargs
             )
 
         else:
