@@ -4,14 +4,14 @@
 
 import numpy as np
 
-from pde import CartesianGrid, CylindricalGrid, ScalarField, VectorField
-from pde.grids.operators import cylindrical as ops
+from pde import CartesianGrid, CylindricalSymGrid, ScalarField, VectorField
+from pde.grids.operators import cylindrical_sym as ops
 
 
 def test_laplace_cyl():
     """ test the implementation of the laplace operator """
     for boundary_z in ["periodic", "derivative"]:
-        grid = CylindricalGrid(
+        grid = CylindricalSymGrid(
             4, (0, 5), (8, 16), periodic_z=(boundary_z == "periodic")
         )
         a_2d = np.random.uniform(0, 1, grid.shape)
@@ -24,7 +24,7 @@ def test_laplace_cyl():
 
 def test_laplacian_field_cyl():
     """ test the gradient operator """
-    grid = CylindricalGrid(2 * np.pi, [0, 2 * np.pi], [8, 16], periodic_z=True)
+    grid = CylindricalSymGrid(2 * np.pi, [0, 2 * np.pi], [8, 16], periodic_z=True)
     r, z = grid.cell_coords[..., 0], grid.cell_coords[..., 1]
     s = ScalarField(grid, data=np.cos(r) + np.sin(z))
     s_lap = s.laplace(bc="natural")
@@ -35,7 +35,7 @@ def test_laplacian_field_cyl():
 
 def test_gradient_field_cyl():
     """ test the gradient operator"""
-    grid = CylindricalGrid(2 * np.pi, [0, 2 * np.pi], [8, 16], periodic_z=True)
+    grid = CylindricalSymGrid(2 * np.pi, [0, 2 * np.pi], [8, 16], periodic_z=True)
     r, z = grid.cell_coords[..., 0], grid.cell_coords[..., 1]
     s = ScalarField(grid, data=np.cos(r) + np.sin(z))
     v = s.gradient(bc="natural")
@@ -47,7 +47,7 @@ def test_gradient_field_cyl():
 
 def test_divergence_field_cyl():
     """ test the divergence operator """
-    grid = CylindricalGrid(2 * np.pi, [0, 2 * np.pi], [8, 16], periodic_z=True)
+    grid = CylindricalSymGrid(2 * np.pi, [0, 2 * np.pi], [8, 16], periodic_z=True)
     r, z = grid.cell_coords[..., 0], grid.cell_coords[..., 1]
     data = [np.cos(r) + np.sin(z) ** 2, np.cos(r) ** 2 + np.sin(z), np.zeros_like(r)]
     v = VectorField(grid, data=data)
@@ -59,7 +59,7 @@ def test_divergence_field_cyl():
 
 def test_vector_gradient_divergence_field_cyl():
     """ test the divergence operator """
-    grid = CylindricalGrid(2 * np.pi, [0, 2 * np.pi], [8, 16], periodic_z=True)
+    grid = CylindricalSymGrid(2 * np.pi, [0, 2 * np.pi], [8, 16], periodic_z=True)
     r, z = grid.cell_coords[..., 0], grid.cell_coords[..., 1]
     data = [np.cos(r) + np.sin(z) ** 2, np.cos(r) ** 2 + np.sin(z), np.zeros_like(r)]
     v = VectorField(grid, data=data)
@@ -72,7 +72,7 @@ def test_vector_gradient_divergence_field_cyl():
 def test_findiff_cyl():
     """test operator for a simple cylindrical grid. Note that we only
     really test the polar symmetry"""
-    grid = CylindricalGrid(1.5, [0, 1], (3, 2), periodic_z=True)
+    grid = CylindricalSymGrid(1.5, [0, 1], (3, 2), periodic_z=True)
     _, r1, r2 = grid.axes_coords[0]
     np.testing.assert_array_equal(grid.discretization, np.full(2, 0.5))
     s = ScalarField(grid, [[1, 1], [2, 2], [4, 4]])
@@ -105,7 +105,7 @@ def test_findiff_cyl():
 
 def test_grid_laplace():
     """ test the cylindrical implementation of the laplace operator """
-    grid_cyl = CylindricalGrid(6, (0, 4), (4, 4))
+    grid_cyl = CylindricalSymGrid(6, (0, 4), (4, 4))
     grid_cart = CartesianGrid([[-5, 5], [-5, 5], [0, 4]], [10, 10, 4])
 
     a_2d = ScalarField.from_expression(grid_cyl, expression="exp(-5 * r) * cos(z / 3)")
@@ -120,7 +120,7 @@ def test_grid_laplace():
 
 def test_gradient_squared():
     """ compare gradient squared operator """
-    grid = CylindricalGrid(2 * np.pi, [0, 2 * np.pi], 64)
+    grid = CylindricalSymGrid(2 * np.pi, [0, 2 * np.pi], 64)
     field = ScalarField.random_harmonic(grid, modes=1)
     s1 = field.gradient("natural").to_scalar("squared_sum")
     s2 = field.gradient_squared("natural", central=True)
@@ -132,7 +132,7 @@ def test_gradient_squared():
 
 def test_grid_div_grad():
     """ compare div grad to laplacian """
-    grid = CylindricalGrid(2 * np.pi, (0, 2 * np.pi), (16, 16), periodic_z=True)
+    grid = CylindricalSymGrid(2 * np.pi, (0, 2 * np.pi), (16, 16), periodic_z=True)
     r, z = grid.cell_coords[..., 0], grid.cell_coords[..., 1]
     arr = np.cos(r) + np.sin(z)
 
